==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'URL của website bạn', # MODIF
	'form_pet_aucune_signature' => 'Không ký hiệu nào phù hợp với mã số này...', # MODIF
	'form_pet_confirmation' => 'Xin xác nhận chữ ký của bạn:',
	'form_pet_deja_signe' => 'Bạn đã ký văn bản này.',
	'form_pet_envoi_mail_confirmation' => 'Một email xác nhận đã được gửi cho bạn. Bạn nên vào địa chỉ URL đề cập trong email đó để xác nhận chữ ký của mình.', # MODIF
	'form_pet_mail_confirmation' => 'Chào bạn,

Bạn yêu cầu ký vào thỉnh nguyện thư @titre@.

Bạn cung cấp các chi tiết sau:
    Tên: @nom_email@
    Web: @nom_site@ - @url_site@

QUAN TRỌNG...
Để xác nhận chữ ký của bạn, và địa chỉ sau đây (nếu không, lời yêu cầu của bạn sẽ bị từ chối):
    @url@

Cám ơn sự tham gia của bạn.', # MODIF
	'form_pet_nom_site2' => 'Tên trang web của bạn', # MODIF
	'form_pet_probleme_liens' => 'Sửa đổi phần nội dung, xin lấy ra các hyperlink.',
	'form_pet_probleme_technique' => 'Trục trặc kỹ thuật, chữ ký bị đình trệ trong giây lát.',
	'form_pet_signature_validee' => 'Chữ ký bạn được xác nhận. Cám ơn bạn!',
	'form_pet_site_deja_enregistre' => 'Website này đã được ghi danh',
	'form_pet_url_invalide' => 'URL bạn cho vào không đúng.',
	'form_pet_votre_email' => 'Địa chỉ email của bạn',
	'form_pet_votre_nom' => 'Tên hay bí danh', # MODIF
	'form_pet_votre_site' => 'Nếu bạn có một trang web, bạn có thể cho biết tên của nó dưới đây',

	// I
	'info_adresse_email' => 'ĐỊA CHỈ EMAIL:',
	'info_signature_supprimee' => 'Chữ ký đã được xoá',
	'info_signature_supprimee_erreur' => 'Lỗi: code để xoá này không liên hệ đến bất kỳ chữ ký nào', # MODIF
	'info_site_web' => 'WEB SITE:',

	// L
	'lien_reponse_article' => 'Hồi âm bài này'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Dùng thỉnh nguyện thư ',
	'bouton_radio_pas_petition' => 'Không dùng',
	'bouton_radio_petition_activee' => 'Thỉnh nguyện thư được mở lên',
	'bouton_radio_supprimer_petition' => 'Xóa thỉnh nguyện thư',

	// F
	'form_pet_adresse_site' => 'URL của website bạn', # MODIF
	'form_pet_aucune_signature' => 'Không ký hiệu nào phù hợp với mã số này...', # MODIF
	'form_pet_confirmation' => 'Xin xác nhận chữ ký của bạn:',
	'form_pet_deja_signe' => 'Bạn đã ký văn bản này.',
	'form_pet_envoi_mail_confirmation' => 'Một email xác nhận đã được gửi cho bạn. Bạn nên vào địa chỉ URL đề cập trong email đó để xác nhận chữ ký của mình.', # MODIF
	'form_pet_mail_confirmation' => 'Chào bạn,

Bạn yêu cầu ký vào thỉnh nguyện thư @titre@.

Bạn cung cấp các chi tiết sau:
    Tên: @nom_email@
    Web: @nom_site@ - @url_site@

QUAN TRỌNG...
Để xác nhận chữ ký của bạn, và địa chỉ sau đây (nếu không, lời yêu cầu của bạn sẽ bị từ chối):
    @url@

Cám ơn sự tham gia của bạn.', # MODIF
	'form_pet_nom_site2' => 'Tên trang web của bạn', # MODIF
	'form_pet_probleme_liens' => 'Sửa đổi phần nội dung, xin lấy ra các hyperlink.',
	'form_pet_probleme_technique' => 'Trục trặc kỹ thuật, chữ ký bị đình trệ trong giây lát.',
	'form_pet_signature_validee' => 'Chữ ký bạn được xác nhận. Cám ơn bạn!',
	'form_pet_site_deja_enregistre' => 'Website này đã được ghi danh',
	'form_pet_url_invalide' => 'URL bạn cho vào không đúng.',
	'form_pet_votre_email' => 'Địa chỉ email của bạn',
	'form_pet_votre_nom' => 'Tên hay bí danh', # MODIF
	'form_pet_votre_site' => 'Nếu bạn có một trang web, bạn có thể cho biết tên của nó dưới đây',

	// I
	'info_adresse_email' => 'ĐỊA CHỈ EMAIL:',
	'info_signature_supprimee' => 'Chữ ký đã được xoá',
	'info_signature_supprimee_erreur' => 'Lỗi: code để xoá này không liên hệ đến bất kỳ chữ ký nào', # MODIF
	'info_site_web' => 'WEB SITE:',

	// L
	'lien_reponse_article' => 'Hồi âm bài này'
);

?>
